#!/usr/bin/env python
# -*- coding: utf8 -*-

class BaseFeed:
	""" Grundversion des Feeds, der von den einzelnen Feedformaten implementiert werden kann.
		Diese Datei ist eigentlich nutzlos, aber dient als Dokumentation und Referenz,
		wie weitere Feed-Arten implementiert werden können.
	"""
	
	def isApplicable(self, feed):
		""" Gibt true zurück, wenn der Feed vom Typ ist, der hier unterstützt wird. """
		raise NotImplementedError( "Should have implemented this" )
		
	def setSelfReference(self, feed, url):
		""" Damit kein Feed-Reader auf die Idee kommt, den Originalfeed zu beziehen,
			werden mit dieser Methode alle Selbstreferenzen auf 'url' gesetzt.
		"""
		raise NotImplementedError( "Should have implemented this" )		

	def getItems(self, feed):
		""" Gibt alle Einträge eines Feeds als Array zurück. """
		raise NotImplementedError( "Should have implemented this" )

	def getEnclosures(self, item):
		""" Gibt Enclosures eines Eintrags als Array zurück.
			Format: Ein ElementTree Node. Muss also speziell verändert werden. """
		raise NotImplementedError( "Should have implemented this" )
	
	def getUrlOfEnclosure(self, enclosure):
		""" Holt die URL aus einem Enclosure-Element. """
		raise NotImplementedError( "Should have implemented this" )

	def setUrlOfEnclosure(self, enclosure, url):
		""" Überschreibt die URL in einem Enclosure-Element. """
		raise NotImplementedError( "Should have implemented this" )
