#!/usr/bin/env python
# -*- coding: utf8 -*-

import urlparse
import os
import bitloveUrlParser

# Importiere alle unterstützten Typen
import atomfeed, rssfeed

class Feedmanipulator:
	def __init__(self):
		self.feedtypes = []
		
		# Registriere die FeedHandler - ein bisschen Factory...
		self.feedtypes.append(atomfeed.AtomFeed())
		self.feedtypes.append(rssfeed.RSSFeed())
	
	def getFeedHandler(self, feed):
		""" Sucht zum Feed die passende Klasse um darauf zugreifen zu können. """
		for feedHandler in self.feedtypes:
			if(feedHandler.isApplicable(feed)):
				return feedHandler
		raise Exception('Unsupported feedtype.')
	
	def modifyFeed(self, feed, rootDirectory, mediaPath, serverPrefix, feedurl):
		""" Manipulation des Feeds:
			Der Feed wird von allen Einträgen befreit, zu denen keine Enclosures vorhanden sind.
			Die URLs aller verbleibenden Einträge werden auf die lokale Adresse umgeschrieben.
			
			feed -> ElementTree Repräsentation des Feeds
			rootDirectory -> Wurzelverzeichnis (ohne anschließendes "/")
			mediaPath -> Pfad zum Ordner mit den Mediendateien, relativ zum Wurzelverzeichnis (beginnt und endet mit "/")
			serverPrefix -> Prefix, der auf den kleinen Webserver dieses Tools zeigt. Ohne "/" am Ende. """
		
		# Erzeuge eine Child -> Parent Map, um auf die Elternelemente zugreifen zu können
		parent_map = dict((c, p) for p in feed.getiterator() for c in p)
		
		# Handler für den Feed holen
		feedHandler = self.getFeedHandler(feed)
		
		# Liste aller vorhandenen Dateien für diesen Pfad holen
		mediafiles = os.listdir(rootDirectory + mediaPath)
		
		# Selbstreferenz des Feeds korrigieren
		feedHandler.setSelfReference(feed, serverPrefix + '/' + feedurl)
		
		for item in feedHandler.getItems(feed):
			# Prüfen, ob die Dateien in den Enclosures existieren
			enclosures = feedHandler.getEnclosures(item)
			
			keepItem = False # Eintrag im Feed behalten?
			for element in enclosures:
				urlparts = urlparse.urlparse(feedHandler.getUrlOfEnclosure(element))
				filename = urlparts[2].split('/')[-1].split(".torrent")[0]
				if(filename in mediafiles):
					#Datei ist schon vorhanden also lokalen Link ausgeben
					keepItem = True
					feedHandler.setUrlOfEnclosure(element, serverPrefix + "/load"+ mediaPath + filename)
					feedHandler.setTypeOfEnclosure(element, "") #mimetyp entfernen damit Clients welche BitTorrent herausfiltern trotzdem laden
				else:
					# Datei ist noch nicht vorhanden - also Torrent-Link angeben, wenn dieser aufgerufen wird der Torrent Inhalt ausgeliefert wird
					keepItem = True
					feedHandler.setUrlOfEnclosure(element, serverPrefix + "/torrent/" + feedHandler.getUrlOfEnclosure(element).rsplit(".torrent",1)[0])
					feedHandler.setTypeOfEnclosure(element, "") #mimetyp entfernen damit Clients welche BitTorrent herausfiltern trotzdem laden

			
			if(not keepItem):
				# Entferne den Feedeintrag
				parent_map[item].remove(item)
		
		return feed
				
			
			
			
			
			
